@@ -1,5 +1,5 @@
 package Sim::OPT::Sim;
-# Copyright (C) 2008-2022 by Gian Luca Brunetti and Politecnico di Milano.
+# Copyright (C) 2008-2023 by Gian Luca Brunetti and Politecnico di Milano.
 # This is the module Sim::OPT::Sim of Sim::OPT, a program for detailed metadesign managing parametric explorations through the ESP-r building performance simulation platform and performing optimization by block coordinate descent.
 # This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
@@ -39,7 +39,7 @@ use warnings::unused;
 
 our @EXPORT = qw( sim ); # our @EXPORT = qw( );
 
-$VERSION = '0.085'; # our $VERSION = '';
+$VERSION = '0.087'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Sim is the module used by Sim::OPT to launch simulations once the models have been built.';
 
 #########################################################################################
@@ -235,9 +235,9 @@ sub sim
           if ( $tooltype eq "esp-r" )
           {
             my $launchline;
-            if ( ( -e "../tmp/*.res" ) or ( -e "../tmp/*.fl" ) or ( -e "../tmp/*.mfr" ) )
+            if ( ( -e "./*.res" ) or ( -e "./*.fl" ) or ( -e "./*.mfr" ) )
             {
-              $launchline = "rm ../tmp/*.res \n rm ../tmp/*.fl \n rm ../tmp/*.mfr \n cd $simelt/cfg/ \n bps -file $fileconfig -mode script";
+              $launchline = "rm ./*.res \n rm ./*.fl \n rm ./*.mfr \n cd $simelt/cfg/ \n bps -file $fileconfig -mode script";
             }
             else
             {
@@ -257,8 +257,8 @@ sub sim
               {
                 my $fileconfigroot = $fileconfig;
                 $fileconfigroot =~ s/\.cfg//;
-                $resfile = "$simelt/tmp/$fileconfigroot.res";
-                $flfile = "$simelt/tmp/$fileconfigroot.mfr";
+                $resfile = "$simelt/cfg/$fileconfigroot.res";
+                $flfile = "$simelt/cfg/$fileconfigroot.mfr";
                 $shortresfile = "$fileconfigroot.res";
                 $shortflfile = "$fileconfigroot.mfr";
               }
